Package: timeDate
Title: Rmetrics - Chronological and Calendar Objects
Date: 2015-01-22
Version: 3012.100
Author: Rmetrics Core Team,
	Diethelm Wuertz [aut],
	Tobias Setz [cre],
	Yohan Chalabi [ctb],
	Martin Maechler [ctb],
	Joe W. Byers [ctb]
Maintainer: Tobias Setz <tobias.setz@rmetrics.org>
Description: Environment for teaching 
	"Financial Engineering and Computational Finance".
	Managing chronological and calendar objects.
Depends: R (>= 2.15.1), graphics, utils, stats, methods
Suggests: date, RUnit
Note: SEVERAL PARTS ARE STILL PRELIMINARY AND MAY BE CHANGED IN THE
        FUTURE. THIS TYPICALLY INCLUDES FUNCTION AND ARGUMENT NAMES, AS
        WELL AS DEFAULTS FOR ARGUMENTS AND RETURN VALUES.
LazyData: yes
License: GPL (>= 2)
URL: https://www.rmetrics.org
Packaged: 2015-01-23 00:36:51 UTC; Tobi
NeedsCompilation: no
Repository: CRAN
Date/Publication: 2015-01-23 09:30:30
Built: R 3.3.2; ; 2017-04-24 09:36:02 UTC; windows
