## GNB: To make maintenance easier, I rearranged this file by topic (see r6349),
##   revealing missing entries in the holiday lists on the way. The two big
##   sections (financial centers and holidays) are enclosed by suitable
##   begin/end comments, so can be easily re-generated from the respective lists
##   producing functions 'listHolidays' and 'listFinCenter'). Some financial
##   centers are not in the list produced by 'listFiCenter()' and are put just
##   before the main list. They are present for convenience and/or backward
##   compatibility.
##
## Before r6349 this file was updated using scripts based on roxigen
## comments. The procedure can be found at the top of NAMESPACE in earlier
## revisions.

import(methods)
importFrom(stats, start, end, window, approx, na.omit, var, frequency)
importFrom("graphics", axis.POSIXct)
importFrom("utils", str, .DollarNames)

S3method("[<-",timeDate)
S3method(as.Date,timeDate)
S3method(as.POSIXct,timeDate)
S3method(as.POSIXlt,timeDate)
S3method(as.character,timeDate)
S3method(as.data.frame,timeDate)
S3method(as.double,timeDate)
S3method(as.list,timeDate)
S3method(as.timeDate,Date)
S3method(as.timeDate,POSIXt)
S3method(as.timeDate,default)
S3method(as.timeDate,timeDate)
S3method(c,timeDate)
S3method(cut,timeDate)
S3method(diff,timeDate)
S3method(end,timeDate)
S3method(format,timeDate)
S3method(kurtosis,POSIXct)
S3method(kurtosis,POSIXlt)
S3method(kurtosis,data.frame)
S3method(kurtosis,default)
S3method(length,timeDate)
S3method(max,timeDate)
S3method(min,timeDate)
S3method(pretty,timeDate)
S3method(print, timeDate_summary)
S3method(range,timeDate)
S3method(rep,timeDate)
S3method(rev,timeDate)
S3method(round,timeDate)
S3method(seq,timeDate)
S3method(skewness,POSIXct)
S3method(skewness,POSIXlt)
S3method(skewness,data.frame)
S3method(skewness,default)
S3method(sort,timeDate)
S3method(start,timeDate)
S3method(summary,timeDate)
S3method(trunc,timeDate)
S3method(unique,timeDate)
S3method(window,timeDate)

S3method(julian,timeDate)
S3method(months,timeDate)
S3method(quarters,timeDate)
S3method(weekdays,timeDate)

S3method(frequency,timeDate)


S3method(.DollarNames, timeDate)


exportClasses(timeDate)

exportMethods(
    "+", "-", Ops,
    "[",
    abline,
    align,
    atoms,
    finCenter, "finCenter<-",
    getDataPart,
    initialize,
    is.na,
    isDaily, isMonthly, isQuarterly, isRegular,
    lines, plot, points,
    names,
    sample,
    show,
    timeDate
)

export(
    .endpoints # this is documented
)

export(
    Sys.timeDate,
    align, alignDaily, alignMonthly, alignQuarterly,
    as.Date.timeDate, # To avoid that zoo package masks as.Date.timeDate?
    as.timeDate,
    atoms,
    axis.timeDate,
    blockEnd, blockStart,
    dayOfWeek, dayOfYear,
    difftimeDate,
    finCenter, "finCenter<-",
    getRmetricsOption,
    getRmetricsOptions, # compatibility
    holiday,
    holidayLONDON, holidayNERC, holidayNYSE, holidayTSX, holidayZURICH,
    isBizday, isDaily, isHoliday, isMonthly, isQuarterly, isRegular,
    isWeekday, isWeekend,
    kurtosis,
    listFinCenter, listHolidays,
    midnightStandard, midnightStandard2,
    monthlyRolling, periodicallyRolling,
    periods,
    rulesFinCenter,
    setRmetricsOptions,
    skewness,
    strptimeDate,
    timeCalendar,
    timeDate,
    timeFirstDayInMonth, timeFirstDayInQuarter, timeLastDayInMonth,
    timeLastDayInQuarter, timeLastNdayInMonth,
    timeNdayOnOrAfter, timeNdayOnOrBefore, timeNthNdayInMonth,
    timeSequence,
    whichFormat,

    earlyCloseNYSE,
    frequency
)

export(GBBankHoliday) # deprecated, superseded by GBSpringBankHoliday
export(GBMayDay) # deprecated, superseded by EarlyMayBankHoliday

## begin: holidays
export(
    Advent1st,
    Advent2nd,
    Advent3rd,
    Advent4th,
    AllSaints,
    AllSouls,
    Annunciation,
    Ascension,
    AshWednesday,
    AssumptionOfMary,
    BirthOfVirginMary,
    BoxingDay,
    CAFamilyDay,
    CACanadaDay,
    CACivicProvincialHoliday,
    CALabourDay,
    CAThanksgivingDay,
    CAVictoriaDay,
    CHAscension,
    CHBerchtoldsDay,
    CHConfederationDay,
    CHKnabenschiessen,
    CHSechselaeuten,
    CaRemembranceDay,
    CelebrationOfHolyCross,
    ChristTheKing,
    ChristmasDay,
    ChristmasEve,
    CorpusChristi,
    DEAscension,
    DEChristmasEve,
    DECorpusChristi,
    DEGermanUnity,
    DENewYearsEve,
    Easter,
    EasterMonday,
    EasterSunday,
    Epiphany,
    FRAllSaints,
    FRArmisticeDay,
    FRAscension,
    FRAssumptionVirginMary,
    FRBastilleDay,
    FRFetDeLaVictoire1945,
    GBSpringBankHoliday,
    GBEarlyMayBankHoliday,
    GBMilleniumDay, # deprecated
    specialHolidayGB,
    GBSummerBankHoliday,
    GoodFriday,

    InternationalWomensDay,

    ITAllSaints,
    ITAssumptionOfVirginMary,
    ITEpiphany,
    ITImmaculateConception,
    ITLiberationDay,
    ITStAmrose,
    JPVernalEquinox,
    JPAutumnalEquinox,
    JPBankHolidayDec31,
    JPBankHolidayJan2,
    JPBankHolidayJan3,
    JPBunkaNoHi,
    JPChildrensDay,
    JPComingOfAgeDay,
    JPConstitutionDay,
    JPEmperorsBirthday,
    JPGantan,
    JPGreeneryDay,
    JPHealthandSportsDay,
    JPKeirouNOhi,  # 2023-11-27 deprecated
    JPKeirouNoHi,  # 2023-11-27 new, replaces the above
    JPKenkokuKinenNoHi,
    JPKenpouKinenBi,
    JPKinrouKanshaNoHi,
    JPKodomoNoHi,
    JPKokuminNoKyujitu,
    JPMarineDay,
    JPMidoriNoHi,
    JPMountainDay, # new 2023-11-27
    JPNatFoundationDay,
    JPNationHoliday,
    JPNationalCultureDay,
    JPNewYearsDay,
    JPRespectForTheAgedDay,
    JPSeijinNoHi,
    JPShuubunNoHi,
    JPTaiikuNoHi,
    JPTennouTanjyouBi,
    JPThanksgivingDay,
    JPUmiNoHi,
    LaborDay,
    MassOfArchangels,
    NewYearsDay,
    PalmSunday,
    Pentecost,
    PentecostMonday,
    PresentationOfLord,
    Quinquagesima,
    RogationSunday,
    Septuagesima,
    SolemnityOfMary,
    TransfigurationOfLord,
    TrinitySunday,
    USCPulaskisBirthday,
    USChristmasDay,
    USColumbusDay,
    USDecorationMemorialDay,
    USElectionDay,
    USGoodFriday,
    USInaugurationDay,
    USIndependenceDay,
    USLaborDay,
    USLincolnsBirthday,
    USMLKingsBirthday,
    USMemorialDay,
    USNewYearsDay,
    USPresidentsDay,
    USThanksgivingDay,
    USVeteransDay,
    USWashingtonsBirthday,
    USJuneteenthNationalIndependenceDay
)
## end:   holidays

## alternative or old names of financial centers
export(
    AST,
    BuenosAires,
    CET,
    CST,
    EET,
    EST,
    Eastern,
    Frankfurt,
    HongKong,
    KualaLumpur,
    LosAngeles,
    MST,
    MexicoCity,
    NewYork,
    PST,
    Pacific
)

## begin: FinCenter
export(
    "Blanc-Sablon",
    "Port-au-Prince",
    "Porto-Novo",
    Abidjan,
    Accra,
    Adak,
    Addis_Ababa,
    Adelaide,
    Aden,
    Algiers,
    Almaty,
    Amman,
    Amsterdam,
    Anadyr,
    Anchorage,
    Andorra,
    Anguilla,
    Antananarivo,
    Antigua,
    Apia,
    Aqtau,
    Aqtobe,
    Araguaina,
    Aruba,
    Ashgabat,
    Asmara,
    Asuncion,
    Athens,
    Atikokan,
    Auckland,
    Azores,
    Baghdad,
    Bahia,
    Bahrain,
    Baku,
    Bamako,
    Bangkok,
    Bangui,
    Banjul,
    Barbados,
    Beirut,
    Belem,
    Belgrade,
    Belize,
    Berlin,
    Bermuda,
    Bishkek,
    Bissau,
    Blantyre,
    Boa_Vista,
    Bogota,
    Boise,
    Bratislava,
    Brazzaville,
    Brisbane,
    Broken_Hill,
    Brunei,
    Brussels,
    Bucharest,
    Budapest,
    Buenos_Aires,
    Bujumbura,
    Cairo,
    Calcutta,
    Cambridge_Bay,
    Campo_Grande,
    Canary,
    Cancun,
    Cape_Verde,
    Caracas,
    Casablanca,
    Casey,
    Catamarca,
    Cayenne,
    Cayman,
    Center,
    Ceuta,
    Chagos,
    Chatham,
    Chicago,
    Chihuahua,
    Chisinau,
    Choibalsan,
    Chongqing,
    Christmas,
    Cocos,
    Colombo,
    Comoro,
    Conakry,
    Copenhagen,
    Cordoba,
    Costa_Rica,
    Cuiaba,
    Curacao,
    Currie,
    Dakar,
    Damascus,
    Danmarkshavn,
    Dar_es_Salaam,
    Darwin,
    Davis,
    Dawson,
    Dawson_Creek,
    Denver,
    Detroit,
    Dhaka,
    Dili,
    Djibouti,
    Dominica,
    Douala,
    Dubai,
    Dublin,
    DumontDUrville,
    Dushanbe,
    Edmonton,
    Efate,
    Eirunepe,
    El_Aaiun,
    El_Salvador,
    Enderbury,
    Eucla,
    Fakaofo,
    Faroe,
    Fiji,
    Fortaleza,
    Freetown,
    Funafuti,
    Gaborone,
    Galapagos,
    Gambier,
    Gaza,
    Gibraltar,
    Glace_Bay,
    Godthab,
    Goose_Bay,
    Grand_Turk,
    Grenada,
    Guadalcanal,
    Guadeloupe,
    Guam,
    Guatemala,
    Guayaquil,
    Guernsey,
    Guyana,
    Halifax,
    Harare,
    Harbin,
    Havana,
    Helsinki,
    Hermosillo,
    Hobart,
    Hong_Kong,
    Honolulu,
    Hovd,
    Indianapolis,
    Inuvik,
    Iqaluit,
    Irkutsk,
    Isle_of_Man,
    Istanbul,
    Jakarta,
    Jamaica,
    Jayapura,
    Jersey,
    Jerusalem,
    Johannesburg,
    Johnston,
    Jujuy,
    Juneau,
    Kabul,
    Kaliningrad,
    Kamchatka,
    Kampala,
    Karachi,
    Kashgar,
    Katmandu,
    Kerguelen,
    Khartoum,
    Kiev,
    Kigali,
    Kinshasa,
    Kiritimati,
    Knox,
    Kosrae,
    Krasnoyarsk,
    Kuala_Lumpur,
    Kuching,
    Kuwait,
    Kwajalein,
    La_Paz,
    La_Rioja,
    Lagos,
    Libreville,
    Lima,
    Lindeman,
    Lisbon,
    Ljubljana,
    Lome,
    London,
    Longyearbyen,
    Lord_Howe,
    Los_Angeles,
    Louisville,
    Luanda,
    Lubumbashi,
    Lusaka,
    Luxembourg,
    Macau,
    Maceio,
    Madeira,
    Madrid,
    Magadan,
    Mahe,
    Majuro,
    Makassar,
    Malabo,
    Maldives,
    Malta,
    Managua,
    Manaus,
    Manila,
    Maputo,
    Marengo,
    Mariehamn,
    Marigot,
    Marquesas,
    Martinique,
    Maseru,
    Mauritius,
    Mawson,
    Mayotte,
    Mazatlan,
    Mbabane,
    McMurdo,
    Melbourne,
    Mendoza,
    Menominee,
    Merida,
    Mexico_City,
    Midway,
    Minsk,
    Miquelon,
    Mogadishu,
    Monaco,
    Moncton,
    Monrovia,
    Monterrey,
    Montevideo,
    Monticello,
    Montreal,
    Montserrat,
    Moscow,
    Muscat,
    Nairobi,
    Nassau,
    Nauru,
    Ndjamena,
    New_Salem,
    New_York,
    Niamey,
    Nicosia,
    Nipigon,
    Niue,
    Nome,
    Norfolk,
    Noronha,
    Nouakchott,
    Noumea,
    Novosibirsk,
    Omsk,
    Oral,
    Oslo,
    Ouagadougou,
    Pago_Pago,
    Palau,
    Palmer,
    Panama,
    Pangnirtung,
    Paramaribo,
    Paris,
    Perth,
    Petersburg,
    Phnom_Penh,
    Phoenix,
    Pitcairn,
    Podgorica,
    Ponape,
    Pontianak,
    Port_Moresby,
    Port_of_Spain,
    Porto_Velho,
    Prague,
    Puerto_Rico,
    Pyongyang,
    Qatar,
    Qyzylorda,
    Rainy_River,
    Rangoon,
    Rankin_Inlet,
    Rarotonga,
    Recife,
    Regina,
    Resolute,
    Reunion,
    Reykjavik,
    Riga,
    Rio_Branco,
    Rio_Gallegos,
    Riyadh,
    Rome,
    Rothera,
    Saigon,
    Saipan,
    Sakhalin,
    Samara,
    Samarkand,
    San_Juan,
    San_Marino,
    Santiago,
    Santo_Domingo,
    Sao_Paulo,
    Sao_Tome,
    Sarajevo,
    Scoresbysund,
    Seoul,
    Shanghai,
    Shiprock,
    Simferopol,
    Singapore,
    Skopje,
    Sofia,
    South_Georgia,
    South_Pole,
    St_Barthelemy,
    St_Helena,
    St_Johns,
    St_Kitts,
    St_Lucia,
    St_Thomas,
    St_Vincent,
    Stanley,
    Stockholm,
    Swift_Current,
    Sydney,
    Syowa,
    Tahiti,
    Taipei,
    Tallinn,
    Tarawa,
    Tashkent,
    Tbilisi,
    Tegucigalpa,
    Tehran,
    Tell_City,
    Thimphu,
    Thule,
    Thunder_Bay,
    Tijuana,
    Tirane,
    Tokyo,
    Tongatapu,
    Toronto,
    Tortola,
    Tripoli,
    Truk,
    Tucuman,
    Tunis,
    Ulaanbaatar,
    Urumqi,
    Ushuaia,
    Uzhgorod,
    Vaduz,
    Vancouver,
    Vatican,
    Vevay,
    Vienna,
    Vientiane,
    Vilnius,
    Vincennes,
    Vladivostok,
    Volgograd,
    Vostok,
    Wake,
    Wallis,
    Warsaw,
    Whitehorse,
    Winamac,
    Windhoek,
    Winnipeg,
    Yakutat,
    Yakutsk,
    Yekaterinburg,
    Yellowknife,
    Yerevan,
    Zagreb,
    Zaporozhye,
    Zurich
)
## end:   FinCenter
