#######################################################################
## Note this file has been automatically generated --- Do not edit it.
## 
## The Namespace is generated by using the roxygenize() function from
## the roxygen2 package. Whether a function should be exported is
## directly defined above the function definition within the
## source (R/*.R) files by using the "@export" roxygen tag.
## Further definitions (e.g. about which packages are imported, whether
## to use a source code library or other specialities) can be made
## within the "R/namespace-tags.R" file. See ?namespace_roclet for
## a desciption of available tags.
#######################################################################

S3method("[<-",timeDate)
S3method(as.Date,timeDate)
S3method(as.POSIXct,timeDate)
S3method(as.POSIXlt,timeDate)
S3method(as.character,timeDate)
S3method(as.data.frame,timeDate)
S3method(as.double,timeDate)
S3method(as.list,timeDate)
S3method(as.timeDate,Date)
S3method(as.timeDate,POSIXt)
S3method(as.timeDate,default)
S3method(as.timeDate,timeDate)
S3method(c,timeDate)
S3method(cut,timeDate)
S3method(diff,timeDate)
S3method(end,timeDate)
S3method(format,timeDate)
S3method(kurtosis,POSIXct)
S3method(kurtosis,POSIXlt)
S3method(kurtosis,data.frame)
S3method(kurtosis,default)
S3method(length,timeDate)
S3method(max,timeDate)
S3method(min,timeDate)
S3method(pretty,timeDate)
S3method(range,timeDate)
S3method(rep,timeDate)
S3method(rev,timeDate)
S3method(round,timeDate)
S3method(seq,timeDate)
S3method(skewness,POSIXct)
S3method(skewness,POSIXlt)
S3method(skewness,data.frame)
S3method(skewness,default)
S3method(sort,timeDate)
S3method(start,timeDate)
S3method(summary,timeDate)
S3method(trunc,timeDate)
S3method(unique,timeDate)
S3method(window,timeDate)
export("Blanc-Sablon")
export("Port-au-Prince")
export("Porto-Novo")
export("finCenter<-")
export(.JULIAN)
export(.by2seconds)
export(.day.of.week)
export(.easter)
export(.easterSunday)
export(.endpoints)
export(.formatFinCenter)
export(.genDaylightSavingTime)
export(.isPOSIX)
export(.julian)
export(.last.of.nday)
export(.midnightStandard)
export(.month.day.year)
export(.nth.of.nday)
export(.on.or.after)
export(.on.or.before)
export(.sdate)
export(.sday.of.week)
export(.sjulian)
export(.sleap.year)
export(.subsetByPython)
export(.subsetBySpan)
export(.subsetCode)
export(.whichFormat)
export(AST)
export(Abidjan)
export(Accra)
export(Adak)
export(Addis_Ababa)
export(Adelaide)
export(Aden)
export(Advent1st)
export(Advent2nd)
export(Advent3rd)
export(Advent4th)
export(Algiers)
export(AllSaints)
export(AllSouls)
export(Almaty)
export(Amman)
export(Amsterdam)
export(Anadyr)
export(Anchorage)
export(Andorra)
export(Anguilla)
export(Annunciation)
export(Antananarivo)
export(Antigua)
export(Apia)
export(Aqtau)
export(Aqtobe)
export(Araguaina)
export(Aruba)
export(Ascension)
export(AshWednesday)
export(Ashgabat)
export(Asmara)
export(AssumptionOfMary)
export(Asuncion)
export(Athens)
export(Atikokan)
export(Auckland)
export(Azores)
export(Baghdad)
export(Bahia)
export(Bahrain)
export(Baku)
export(Bamako)
export(Bangkok)
export(Bangui)
export(Banjul)
export(Barbados)
export(Beirut)
export(Belem)
export(Belgrade)
export(Belize)
export(Berlin)
export(Bermuda)
export(BirthOfVirginMary)
export(Bishkek)
export(Bissau)
export(Blantyre)
export(Boa_Vista)
export(Bogota)
export(Boise)
export(BoxingDay)
export(Bratislava)
export(Brazzaville)
export(Brisbane)
export(Broken_Hill)
export(Brunei)
export(Brussels)
export(Bucharest)
export(Budapest)
export(BuenosAires)
export(Buenos_Aires)
export(Bujumbura)
export(CACanadaDay)
export(CACivicProvincialHoliday)
export(CAFamilyDay)
export(CALabourDay)
export(CAThanksgivingDay)
export(CAVictoriaDay)
export(CET)
export(CHAscension)
export(CHBerchtoldsDay)
export(CHConfederationDay)
export(CHKnabenschiessen)
export(CHSechselaeuten)
export(CST)
export(CaRemembranceDay)
export(Cairo)
export(Calcutta)
export(Cambridge_Bay)
export(Campo_Grande)
export(Canary)
export(Cancun)
export(Cape_Verde)
export(Caracas)
export(Casablanca)
export(Casey)
export(Catamarca)
export(Cayenne)
export(Cayman)
export(CelebrationOfHolyCross)
export(Center)
export(Ceuta)
export(Chagos)
export(Chatham)
export(Chicago)
export(Chihuahua)
export(Chisinau)
export(Choibalsan)
export(Chongqing)
export(ChristTheKing)
export(Christmas)
export(ChristmasDay)
export(ChristmasEve)
export(Cocos)
export(Colombo)
export(Comoro)
export(Conakry)
export(Copenhagen)
export(Cordoba)
export(CorpusChristi)
export(Costa_Rica)
export(Cuiaba)
export(Curacao)
export(Currie)
export(DEAscension)
export(DEChristmasEve)
export(DECorpusChristi)
export(DEGermanUnity)
export(DENewYearsEve)
export(Dakar)
export(Damascus)
export(Danmarkshavn)
export(Dar_es_Salaam)
export(Darwin)
export(Davis)
export(Dawson)
export(Dawson_Creek)
export(Denver)
export(Detroit)
export(Dhaka)
export(Dili)
export(Djibouti)
export(Dominica)
export(Douala)
export(Dubai)
export(Dublin)
export(DumontDUrville)
export(Dushanbe)
export(EET)
export(EST)
export(Easter)
export(EasterMonday)
export(EasterSunday)
export(Eastern)
export(Edmonton)
export(Efate)
export(Eirunepe)
export(El_Aaiun)
export(El_Salvador)
export(Enderbury)
export(Epiphany)
export(Eucla)
export(FRAllSaints)
export(FRArmisticeDay)
export(FRAscension)
export(FRAssumptionVirginMary)
export(FRBastilleDay)
export(FRFetDeLaVictoire1945)
export(Fakaofo)
export(Faroe)
export(Fiji)
export(Fortaleza)
export(Frankfurt)
export(Freetown)
export(Funafuti)
export(GBBankHoliday)
export(GBMayDay)
export(GBMilleniumDay)
export(GBSummerBankHoliday)
export(Gaborone)
export(Galapagos)
export(Gambier)
export(Gaza)
export(Gibraltar)
export(Glace_Bay)
export(Godthab)
export(GoodFriday)
export(Goose_Bay)
export(Grand_Turk)
export(Grenada)
export(Guadalcanal)
export(Guadeloupe)
export(Guam)
export(Guatemala)
export(Guayaquil)
export(Guernsey)
export(Guyana)
export(Halifax)
export(Harare)
export(Harbin)
export(Havana)
export(Helsinki)
export(Hermosillo)
export(Hobart)
export(HongKong)
export(Hong_Kong)
export(Honolulu)
export(Hovd)
export(ITAllSaints)
export(ITAssumptionOfVirginMary)
export(ITEpiphany)
export(ITImmaculateConception)
export(ITLiberationDay)
export(ITStAmrose)
export(Indianapolis)
export(Inuvik)
export(Iqaluit)
export(Irkutsk)
export(Isle_of_Man)
export(Istanbul)
export(JPAutumnalEquinox)
export(JPBankHolidayDec31)
export(JPBankHolidayJan2)
export(JPBankHolidayJan3)
export(JPBunkaNoHi)
export(JPChildrensDay)
export(JPComingOfAgeDay)
export(JPConstitutionDay)
export(JPEmperorsBirthday)
export(JPGantan)
export(JPGreeneryDay)
export(JPHealthandSportsDay)
export(JPKeirouNOhi)
export(JPKenkokuKinenNoHi)
export(JPKenpouKinenBi)
export(JPKinrouKanshaNoHi)
export(JPKodomoNoHi)
export(JPKokuminNoKyujitu)
export(JPMarineDay)
export(JPMidoriNoHi)
export(JPNatFoundationDay)
export(JPNationHoliday)
export(JPNationalCultureDay)
export(JPNewYearsDay)
export(JPRespectForTheAgedDay)
export(JPSeijinNoHi)
export(JPShuubunNoHi)
export(JPTaiikuNoHi)
export(JPTennouTanjyouBi)
export(JPThanksgivingDay)
export(JPUmiNoHi)
export(JPVernalEquinox)
export(Jakarta)
export(Jamaica)
export(Jayapura)
export(Jersey)
export(Jerusalem)
export(Johannesburg)
export(Johnston)
export(Jujuy)
export(Juneau)
export(Kabul)
export(Kaliningrad)
export(Kamchatka)
export(Kampala)
export(Karachi)
export(Kashgar)
export(Katmandu)
export(Kerguelen)
export(Khartoum)
export(Kiev)
export(Kigali)
export(Kinshasa)
export(Kiritimati)
export(Knox)
export(Kosrae)
export(Krasnoyarsk)
export(KualaLumpur)
export(Kuala_Lumpur)
export(Kuching)
export(Kuwait)
export(Kwajalein)
export(La_Paz)
export(La_Rioja)
export(LaborDay)
export(Lagos)
export(Libreville)
export(Lima)
export(Lindeman)
export(Lisbon)
export(Ljubljana)
export(Lome)
export(London)
export(Longyearbyen)
export(Lord_Howe)
export(LosAngeles)
export(Los_Angeles)
export(Louisville)
export(Luanda)
export(Lubumbashi)
export(Lusaka)
export(Luxembourg)
export(MST)
export(Macau)
export(Maceio)
export(Madeira)
export(Madrid)
export(Magadan)
export(Mahe)
export(Majuro)
export(Makassar)
export(Malabo)
export(Maldives)
export(Malta)
export(Managua)
export(Manaus)
export(Manila)
export(Maputo)
export(Marengo)
export(Mariehamn)
export(Marigot)
export(Marquesas)
export(Martinique)
export(Maseru)
export(MassOfArchangels)
export(Mauritius)
export(Mawson)
export(Mayotte)
export(Mazatlan)
export(Mbabane)
export(McMurdo)
export(Melbourne)
export(Mendoza)
export(Menominee)
export(Merida)
export(MexicoCity)
export(Mexico_City)
export(Midway)
export(Minsk)
export(Miquelon)
export(Mogadishu)
export(Monaco)
export(Moncton)
export(Monrovia)
export(Monterrey)
export(Montevideo)
export(Monticello)
export(Montreal)
export(Montserrat)
export(Moscow)
export(Muscat)
export(Nairobi)
export(Nassau)
export(Nauru)
export(Ndjamena)
export(NewYearsDay)
export(NewYork)
export(New_Salem)
export(New_York)
export(Niamey)
export(Nicosia)
export(Nipigon)
export(Niue)
export(Nome)
export(Norfolk)
export(Noronha)
export(Nouakchott)
export(Noumea)
export(Novosibirsk)
export(Omsk)
export(Oral)
export(Oslo)
export(Ouagadougou)
export(PST)
export(Pacific)
export(Pago_Pago)
export(Palau)
export(PalmSunday)
export(Palmer)
export(Panama)
export(Pangnirtung)
export(Paramaribo)
export(Paris)
export(Pentecost)
export(PentecostMonday)
export(Perth)
export(Petersburg)
export(Phnom_Penh)
export(Phoenix)
export(Pitcairn)
export(Podgorica)
export(Ponape)
export(Pontianak)
export(Port_Moresby)
export(Port_of_Spain)
export(Porto_Velho)
export(Prague)
export(PresentationOfLord)
export(Puerto_Rico)
export(Pyongyang)
export(Qatar)
export(Quinquagesima)
export(Qyzylorda)
export(Rainy_River)
export(Rangoon)
export(Rankin_Inlet)
export(Rarotonga)
export(Recife)
export(Regina)
export(Resolute)
export(Reunion)
export(Reykjavik)
export(Riga)
export(Rio_Branco)
export(Rio_Gallegos)
export(Riyadh)
export(RogationSunday)
export(Rome)
export(Rothera)
export(Saigon)
export(Saipan)
export(Sakhalin)
export(Samara)
export(Samarkand)
export(San_Juan)
export(San_Marino)
export(Santiago)
export(Santo_Domingo)
export(Sao_Paulo)
export(Sao_Tome)
export(Sarajevo)
export(Scoresbysund)
export(Seoul)
export(Septuagesima)
export(Shanghai)
export(Shiprock)
export(Simferopol)
export(Singapore)
export(Skopje)
export(Sofia)
export(SolemnityOfMary)
export(South_Georgia)
export(South_Pole)
export(St_Barthelemy)
export(St_Helena)
export(St_Johns)
export(St_Kitts)
export(St_Lucia)
export(St_Thomas)
export(St_Vincent)
export(Stanley)
export(Stockholm)
export(Swift_Current)
export(Sydney)
export(Syowa)
export(Sys.timeDate)
export(Tahiti)
export(Taipei)
export(Tallinn)
export(Tarawa)
export(Tashkent)
export(Tbilisi)
export(Tegucigalpa)
export(Tehran)
export(Tell_City)
export(Thimphu)
export(Thule)
export(Thunder_Bay)
export(Tijuana)
export(Tirane)
export(Tokyo)
export(Tongatapu)
export(Toronto)
export(Tortola)
export(TransfigurationOfLord)
export(TrinitySunday)
export(Tripoli)
export(Truk)
export(Tucuman)
export(Tunis)
export(USCPulaskisBirthday)
export(USChristmasDay)
export(USColumbusDay)
export(USDecorationMemorialDay)
export(USElectionDay)
export(USGoodFriday)
export(USInaugurationDay)
export(USIndependenceDay)
export(USLaborDay)
export(USLincolnsBirthday)
export(USMLKingsBirthday)
export(USMemorialDay)
export(USNewYearsDay)
export(USPresidentsDay)
export(USThanksgivingDay)
export(USVeteransDay)
export(USWashingtonsBirthday)
export(Ulaanbaatar)
export(Urumqi)
export(Ushuaia)
export(Uzhgorod)
export(Vaduz)
export(Vancouver)
export(Vatican)
export(Vevay)
export(Vienna)
export(Vientiane)
export(Vilnius)
export(Vincennes)
export(Vladivostok)
export(Volgograd)
export(Vostok)
export(Wake)
export(Wallis)
export(Warsaw)
export(Whitehorse)
export(Winamac)
export(Windhoek)
export(Winnipeg)
export(Yakutat)
export(Yakutsk)
export(Yekaterinburg)
export(Yellowknife)
export(Yerevan)
export(Zagreb)
export(Zaporozhye)
export(Zurich)
export(align)
export(alignDaily)
export(alignMonthly)
export(alignQuarterly)
export(as.Date.timeDate)
export(as.timeDate)
export(atoms)
export(axis.timeDate)
export(blockEnd)
export(blockStart)
export(dayOfWeek)
export(dayOfYear)
export(difftimeDate)
export(finCenter)
export(getRmetricsOption)
export(getRmetricsOptions)
export(holiday)
export(holidayLONDON)
export(holidayNERC)
export(holidayNYSE)
export(holidayTSX)
export(holidayZURICH)
export(isBizday)
export(isDaily)
export(isHoliday)
export(isMonthly)
export(isQuarterly)
export(isRegular)
export(isWeekday)
export(isWeekend)
export(kurtosis)
export(listFinCenter)
export(listHolidays)
export(midnightStandard)
export(midnightStandard2)
export(monthlyRolling)
export(periodicallyRolling)
export(periods)
export(rulesFinCenter)
export(setRmetricsOptions)
export(skewness)
export(strptimeDate)
export(timeCalendar)
export(timeDate)
export(timeFirstDayInMonth)
export(timeFirstDayInQuarter)
export(timeLastDayInMonth)
export(timeLastDayInQuarter)
export(timeLastNdayInMonth)
export(timeNdayOnOrAfter)
export(timeNdayOnOrBefore)
export(timeNthNdayInMonth)
export(timeSequence)
export(whichFormat)
exportClasses(timeDate)
exportMethods("+")
exportMethods("-")
exportMethods("[")
exportMethods("finCenter<-")
exportMethods(Ops)
exportMethods(abline)
exportMethods(align)
exportMethods(atoms)
exportMethods(finCenter)
exportMethods(frequency)
exportMethods(getDataPart)
exportMethods(initialize)
exportMethods(is.na)
exportMethods(isDaily)
exportMethods(isMonthly)
exportMethods(isQuarterly)
exportMethods(isRegular)
exportMethods(julian)
exportMethods(lines)
exportMethods(months)
exportMethods(names)
exportMethods(plot)
exportMethods(points)
exportMethods(sample)
exportMethods(show)
exportMethods(timeDate)
import(graphics)
import(methods)
import(stats)
import(utils)
